@@ -1,11 +1,10 @@
 import os
 import sys
 import tokenize
-from typing import Tuple, IO
+from typing import IO, Tuple
 
 from . import sql_formatter
 
-
 SQLFORMAT_COMMENT = "sqlformat"
 
 POSSIBLE_QUOTES = ('"""', "'''", '"', "'")
