@@ -1,38 +1,41 @@
 from sqlvalidator.grammar.sql import (
-    SelectStatement,
-    FunctionCall,
-    Column,
-    Type,
     Alias,
-    String,
-    Integer,
-    Parenthesis,
-    Table,
+    AnalyticsClause,
     ArithmaticOperator,
-    Condition,
-    BooleanCondition,
     Boolean,
-    WhereClause,
+    BooleanCondition,
+    Case,
+    Column,
+    CombinedQueries,
+    Condition,
+    DatePartExtraction,
+    ExceptClause,
+    FunctionCall,
     GroupByClause,
     HavingClause,
+    Index,
+    Integer,
+    Join,
+    LimitClause,
+    Negation,
+    Null,
+    OffsetClause,
+    OnClause,
     OrderByClause,
     OrderByItem,
-    LimitClause,
-    OffsetClause,
-    Null,
-    Join,
-    OnClause,
+    Parenthesis,
+    SelectStatement,
+    String,
+    Table,
+    Type,
     UsingClause,
-    ExceptClause,
-    AnalyticsClause,
+    WhereClause,
     WindowFrameClause,
-    Case,
-    Index,
 )
 from sqlvalidator.grammar.tokeniser import (
-    get_tokens_until_one_of,
     get_tokens_until_closing_parenthesis,
     get_tokens_until_not_in,
+    get_tokens_until_one_of,
 )
 
 
@@ -181,7 +184,11 @@ class FromStatementParser:
                 expression = Table(next_token)
 
         next_token = next(tokens, None)
-        if next_token is not None and next_token not in Join.VALUES:
+        if (
+            next_token is not None
+            and next_token not in Join.VALUES
+            and next_token not in CombinedQueries.SET_OPERATORS
+        ):
             if next_token == "as":
                 with_as = True
                 alias = next(tokens)
@@ -191,6 +198,36 @@ class FromStatementParser:
             expression = Alias(expression, alias, with_as)
             next_token = next(tokens, None)
 
+        while next_token in CombinedQueries.SET_OPERATORS:
+            left_expr = expression
+            expression_tokens, next_token = get_tokens_until_not_in(
+                tokens, CombinedQueries.SET_OPERATORS, first_token=next_token
+            )
+            set_operator = SetOperatorTypeParser.parse(iter(expression_tokens))
+            expression_tokens, next_token = get_tokens_until_one_of(
+                tokens,
+                CombinedQueries.SET_OPERATORS,
+                first_token=next_token,
+            )
+            if expression_tokens[0] == "select":
+                right_expr = SelectStatementParser.parse(iter(expression_tokens[1:]))
+            else:
+                right_expr = FromStatementParser.parse(iter(expression_tokens))
+            expression = CombinedQueries(set_operator, left_expr, right_expr)
+
+            if (
+                next_token is not None
+                and next_token not in CombinedQueries.SET_OPERATORS
+            ):
+                if next_token == "as":
+                    with_as = True
+                    alias = next(tokens)
+                else:
+                    with_as = False
+                    alias = next_token
+                expression = Alias(expression, alias, with_as)
+                next_token = next(tokens, None)
+
         while next_token in Join.VALUES:
             left_expr = expression
             expression_tokens, next_token = get_tokens_until_not_in(
@@ -239,6 +276,12 @@ class JoinTypeParser:
         return " ".join(tokens).upper()
 
 
+class SetOperatorTypeParser:
+    @staticmethod
+    def parse(tokens):
+        return " ".join(tokens).upper()
+
+
 class WhereClauseParser:
     @staticmethod
     def parse(tokens):
@@ -362,8 +405,11 @@ class ExpressionParser:
             expression = Boolean(main_token)
         elif main_token in Null.VALUES:
             expression = Null()
-        elif main_token in Type.VALUES:
-            expression = Type(main_token)
+        elif main_token == Negation.PREDICATE:
+            rest_expression, next_token = ExpressionParser.parse(
+                tokens, is_right_hand=True
+            )
+            expression = Negation(rest_expression)
         elif main_token == "(":
             argument_tokens = get_tokens_until_closing_parenthesis(tokens)
             arguments = ExpressionListParser.parse(iter(argument_tokens))
@@ -390,6 +436,16 @@ class ExpressionParser:
                 arguments = ExpressionListParser.parse(iter(argument_tokens))
                 expression = FunctionCall(main_token, *arguments)
                 next_token = next(tokens, None)
+            elif (
+                next_token is not None
+                and main_token in DatePartExtraction.PARTS
+                and next_token == "from"
+            ):
+                rest_expression = ExpressionParser.parse(tokens)
+                expression = DatePartExtraction(main_token, rest_expression)
+                next_token = next(tokens, None)
+            elif main_token in Type.VALUES:
+                expression = Type(main_token)
             elif next_token is not None and next_token == "[":
                 argument_tokens, next_token = get_tokens_until_one_of(
                     tokens, stop_words=["]"]
