@@ -1,5 +1,7 @@
 from typing import Any
 
+DEFAULT_LINE_LENGTH = 88
+
 
 def transform(obj: Any) -> str:
     if hasattr(obj, "transform"):
@@ -444,7 +446,10 @@ class FunctionCall(Expression):
 
     def __str__(self):
         transformed_args = [transform(arg) for arg in self.args]
-        with_newlines = any("\n" in arg for arg in transformed_args)
+        with_newlines = (
+            any("\n" in arg for arg in transformed_args)
+            or len(", ".join(transformed_args)) > DEFAULT_LINE_LENGTH
+        )
 
         function_str = self.function_name.upper() + "("
         if with_newlines:
@@ -559,7 +564,21 @@ class WindowFrameClause(Expression):
 
 
 class Column(Expression):
-    KEYWORDS = ("_table_suffix", "nfc", "nfkc", "nfd", "nfkd")
+    KEYWORDS = (
+        "_table_suffix",
+        "_partitiondate",
+        "nfc",
+        "nfkc",
+        "nfd",
+        "nfkd",
+        "monday",
+        "tuesday",
+        "wednesday",
+        "thursday",
+        "friday",
+        "saturday",
+        "sunday",
+    )
 
     def __str__(self):
         if self.value in self.KEYWORDS:
@@ -574,12 +593,47 @@ class Column(Expression):
 
 
 class Type(Expression):
-    VALUES = ("int", "float", "day", "month", "timestamp")
+    VALUES = ("int", "float", "day", "month", "timestamp", "int64", "string")
 
     def __str__(self):
         return self.value.upper()
 
 
+class DatePartExtraction(Expression):
+    PARTS = (
+        "microsecond",
+        "second",
+        "minute",
+        "hour",
+        "day",
+        "week",
+        "month",
+        "quarter",
+        "year",
+        "second_microsecond",
+        "minute_microsecond",
+        "minute_second",
+        "hour_microsecond",
+        "hour_second",
+        "hour_minute",
+        "day_microsecond",
+        "day_second",
+        "day_minute",
+        "day_hour",
+        "year_month",
+        "dayofmonth",
+        "dayofweek",
+        "dayofyear",
+    )
+
+    def __init__(self, part, date_expression):
+        super().__init__(date_expression)
+        self.part = part
+
+    def __str__(self):
+        return "{} FROM {}".format(self.part.upper(), transform(self.value))
+
+
 class String(Expression):
     QUOTES = ("'", '"', "`")
     PREFIXES = ("r",)
@@ -633,14 +687,10 @@ class Null(Expression):
 class Boolean(Expression):
     TRUE_VALUES = (
         "true",
-        "t",
-        "y",
         "yes",
     )
     FALSE_VALUES = (
         "false",
-        "f",
-        "n",
         "no",
     )
     BOOLEAN_VALUES = TRUE_VALUES + FALSE_VALUES
@@ -666,7 +716,14 @@ class Parenthesis(Expression):
         self.args = args
 
     def __str__(self):
-        return "({})".format(", ".join(map(transform, self.args)))
+        return "({})".format(
+            ", ".join(
+                "\n" + a.transform(is_subquery=True) + "\n"
+                if isinstance(a, SelectStatement)
+                else transform(a)
+                for a in self.args
+            )
+        )
 
     def __repr__(self):
         return "<Parenthesis: {}>".format(", ".join(map(repr, self.args)))
@@ -893,6 +950,45 @@ class Join(Expression):
         )
 
 
+class CombinedQueries(Expression):
+    SET_OPERATORS = ("union", "intersect", "except")
+
+    def __init__(self, set_operator, left_query, right_query):
+        self.set_operator = set_operator
+        self.left_query = left_query
+        self.right_query = right_query
+
+    def __str__(self):
+        left_query = transform(self.left_query)
+        right_query = transform(self.right_query)
+        if isinstance(self.right_query, Table):
+            right_query = " " + right_query
+        else:
+            right_query = "\n" + right_query
+
+        return "{}\n{}{}".format(left_query, self.set_operator.upper(), right_query)
+
+    def __eq__(self, other):
+        return (
+            type(self) == type(other)
+            and self.set_operator == other.set_operator
+            and self.left_query == other.left_query
+            and self.right_query == other.right_query
+        )
+
+    def __repr__(self):
+        return """<{}:
+  Set Operator: {!r}
+  Left query: {!r}
+  Right query: {!r}
+""".format(
+            self.__class__.__name__,
+            self.set_operator,
+            self.left_query,
+            self.right_query,
+        )
+
+
 class OnClause(Expression):
     pass
 
@@ -971,6 +1067,19 @@ class BooleanCondition(Expression):
         return bool
 
 
+class Negation(Expression):
+    PREDICATE = "not"
+
+    def __init__(self, expression):
+        super().__init__(expression)
+
+    def __str__(self):
+        negation = "NOT"
+        if not isinstance(self.value, Parenthesis):
+            negation += " "
+        return negation + transform(self.value)
+
+
 class ExceptClause(Expression):
     def __init__(self, expression, args):
         super().__init__(expression)
